package Data::Riak::Types;
{
  $Data::Riak::Types::VERSION = '0.9';
}

use strict;
use warnings;

use Moose::Util::TypeConstraints;

# ...

no Moose::Util::TypeConstraints; 1;



=pod

=head1 NAME

Data::Riak::Types

=head1 VERSION

version 0.9

=head1 AUTHOR

Andrew Nelson <anelson at cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Infinity Interactive.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__END__
